==> graphql-web-lite-16.6.0-3.tgz: package/validation/rules/KnownArgumentNamesRule.js <==
var jsutils_didYouMean = require("../../jsutils/didYouMean.js");

var jsutils_suggestionList = require("../../jsutils/suggestionList.js");

var type_directives = require("../../type/directives.js");

var shared = require("../../shared.js");

function KnownArgumentNamesOnDirectivesRule(context) {
  const directiveArgs = Object.create(null);
  const schema = context.getSchema();
  const definedDirectives = schema ? schema.getDirectives() : type_directives.specifiedDirectives;
  for (const directive of definedDirectives) {
    directiveArgs[directive.name] = directive.args.map((arg => arg.name));
  }
  const astDefinitions = context.getDocument().definitions;
  for (const def of astDefinitions) {
    if (def.kind === shared.e.DIRECTIVE_DEFINITION) {
      var _def$arguments;
      const argsNodes = null !== (_def$arguments = def.arguments) && void 0 !== _def$arguments ? _def$arguments : [];
      directiveArgs[def.name.value] = argsNodes.map((arg => arg.name.value));
    }
  }
  return {
    Directive(directiveNode) {
      const directiveName = directiveNode.name.value;
      const knownArgs = directiveArgs[directiveName];
      if (directiveNode.arguments && knownArgs) {
        for (const argNode of directiveNode.arguments) {
          const argName = argNode.name.value;
          if (!knownArgs.includes(argName)) {
            const suggestions = jsutils_suggestionList.suggestionList(argName, knownArgs);
            context.reportError(new shared.GraphQLError(`Unknown argument "${argName}" on directive "@${directiveName}".` + jsutils_didYouMean.didYouMean(suggestions), {
              nodes: argNode
            }));
          }
        }
      }
      return !1;
    }
  };
}

exports.KnownArgumentNamesOnDirectivesRule = KnownArgumentNamesOnDirectivesRule;

exports.KnownArgumentNamesRule = function KnownArgumentNamesRule(context) {
  return {
    ...KnownArgumentNamesOnDirectivesRule(context),
    Argument(argNode) {
      const argDef = context.getArgument();
      const fieldDef = context.getFieldDef();
      const parentType = context.getParentType();
      if (!argDef && fieldDef && parentType) {
        const argName = argNode.name.value;
        const knownArgsNames = fieldDef.args.map((arg => arg.name));
        const suggestions = jsutils_suggestionList.suggestionList(argName, knownArgsNames);
        context.reportError(new shared.GraphQLError(`Unknown argument "${argName}" on field "${parentType.name}.${fieldDef.name}".` + jsutils_didYouMean.didYouMean(suggestions), {
          nodes: argNode
        }));
      }
    }
  };
};

==> graphql-web-lite-16.6.0-4.tgz: package/validation/rules/KnownArgumentNamesRule.js <==
var jsutils_didYouMean = require("../../jsutils/didYouMean.js");

var jsutils_suggestionList = require("../../jsutils/suggestionList.js");

var type_directives = require("../../type/directives.js");

var graphql_web = require("@0no-co/graphql.web");

function KnownArgumentNamesOnDirectivesRule(context) {
  const directiveArgs = Object.create(null);
  const schema = context.getSchema();
  const definedDirectives = schema ? schema.getDirectives() : type_directives.specifiedDirectives;
  for (const directive of definedDirectives) {
    directiveArgs[directive.name] = directive.args.map((arg => arg.name));
  }
  const astDefinitions = context.getDocument().definitions;
  for (const def of astDefinitions) {
    if (def.kind === graphql_web.Kind.DIRECTIVE_DEFINITION) {
      var _def$arguments;
      const argsNodes = null !== (_def$arguments = def.arguments) && void 0 !== _def$arguments ? _def$arguments : [];
      directiveArgs[def.name.value] = argsNodes.map((arg => arg.name.value));
    }
  }
  return {
    Directive(directiveNode) {
      const directiveName = directiveNode.name.value;
      const knownArgs = directiveArgs[directiveName];
      if (directiveNode.arguments && knownArgs) {
        for (const argNode of directiveNode.arguments) {
          const argName = argNode.name.value;
          if (!knownArgs.includes(argName)) {
            const suggestions = jsutils_suggestionList.suggestionList(argName, knownArgs);
            context.reportError(new graphql_web.GraphQLError(`Unknown argument "${argName}" on directive "@${directiveName}".` + jsutils_didYouMean.didYouMean(suggestions), {
              nodes: argNode
            }));
          }
        }
      }
      return !1;
    }
  };
}

exports.KnownArgumentNamesOnDirectivesRule = KnownArgumentNamesOnDirectivesRule;

exports.KnownArgumentNamesRule = function KnownArgumentNamesRule(context) {
  return {
    ...KnownArgumentNamesOnDirectivesRule(context),
    Argument(argNode) {
      const argDef = context.getArgument();
      const fieldDef = context.getFieldDef();
      const parentType = context.getParentType();
      if (!argDef && fieldDef && parentType) {
        const argName = argNode.name.value;
        const knownArgsNames = fieldDef.args.map((arg => arg.name));
        const suggestions = jsutils_suggestionList.suggestionList(argName, knownArgsNames);
        context.reportError(new graphql_web.GraphQLError(`Unknown argument "${argName}" on field "${parentType.name}.${fieldDef.name}".` + jsutils_didYouMean.didYouMean(suggestions), {
          nodes: argNode
        }));
      }
    }
  };
};
